
import * as je from "../jaxa.earth.esm.js";

//【olオブジェクトについて】
//このサンプルでは、HTMLファイル内の<script src="./ol_v10.1.0/ol.js"></script>でolオブジェクトがグローバル変数として読み込まれています。
//OpenLayersをモジュールでインポートして利用する場合は、次のようなolオブジェクトを作成して使用してください。
/*
import ImageCanvas from 'ol/source/ImageCanvas';
import Image from 'ol/layer/Image';

const ol = {
	"source": {
		ImageCanvas
	},
	"layer": {
		Image
	},
};
console.log(ol);
*/

const jelayer = await je.ol.createLayer({
	//OpenLayersのオブジェクトを渡す。詳細は上記の【olオブジェクトについて】を参照。
	ol,


	collection: "https://s3.ap-northeast-1.wasabisys.com/je-pds/cog/v1/JAXA.EORC_ALOS.PRISM_AW3D30.v3.2_global/collection.json",
	band: "DSM",		//省略時は1個目のバンドを表示
	colorMap: {
		min: 0,
		max: 6000,
		colors: "jet",
	},


	// collection: "https://s3.ap-northeast-1.wasabisys.com/je-pds/cog/v1/JAXA.EORC_GSMaP_standard.Gauge.00Z-23Z.v6_daily/collection.json",
	// colorMap: {
	// 	min: 0.1,
	// 	max: 30,
	// 	colors: "jet",
	// 	deleteMin: true,
	// 	deleteMax: true,
	// 	log10: true,
	// },
	// date: new Date(Date.UTC(2023,3-1,20)),		//省略時は一番最新のデータを表示


	// collection: "https://s3.ap-northeast-1.wasabisys.com/je-pds/cog/v1/NASA.EOSDIS_Terra.MODIS_MOD11C1-LST.nighttime.v061_global_half-monthly-normal/collection.json",
	// colorMap: {
	// 	min: -50 + 273.15,
	// 	max: 50 + 273.15,
	// 	colors: "jet",
	// },
	// date: new Date(),


	// opacity: 0.8,

	//バイリニアリサンプリングを使用(未指定時は高速なニアレストネイバーを使用)
	// bilinearResampling: true,
});


//je.ImageCollection、je.Imageを取得
const ic = jelayer.getImageCollection();
const im = jelayer.getImage();
console.log(ic);
console.log(im);


//時間方向の最初と最後の日付
console.log(ic.firstDate());
console.log(ic.lastDate());

//時刻を表示（Dateオブジェクト）
console.log(im.getDate());

//データの日付(有効数字を考慮した画面表示用の文字列)を取得
console.log(im.getFormattedDate());

//投影法を取得
console.log(ic.getProjection());

//データのBBOXを取得
console.log(ic.getBbox());

//凡例を表示
document.body.appendChild(jelayer.getLegend(300, 20, 10));

//その他、je.ImageCollection、je.Imageの機能を利用可能
//(je.getImage、je.ImageCollection、je.Imageのサンプル参照)


//OpenLayersを作成
const projection = "EPSG:4326";
const map = new ol.Map({
	target: "map",
	pixelRatio: 1,

	layers: [
		new ol.layer.Tile({
			// source: new ol.source.OSM(),
			source: new ol.source.XYZ({
				//https://maps.gsi.go.jp/development/ichiran.html
				url: "https://cyberjapandata.gsi.go.jp/xyz/std/{z}/{x}/{y}.png",
			}),
		}),

		//作成したレイヤーを追加
		jelayer,
	],

	view: new ol.View({
		//全世界を初期位置にする場合
		center: ol.proj.fromLonLat([0, 0], projection),
		zoom: 0,

		//日本周辺を初期位置にする場合
		// center: ol.proj.fromLonLat([138, 36], projection),
		// zoom: 5,
		
		//投影法(必須)
		projection,

		//スクロール範囲を制限する場合
		// extent: [-360,-90,360,90],
	}),
});

//クリックした場所の値を取得する
map.on("click", async e => {
	//クリックした位置のピクセル座標(div#mapの左上が(0,0)、右下が(width-1,height-1))
	const [i, j] = e.pixel;

	const image = jelayer.getImage();

	if (image.ready()) {
		//読み込みが完了している場合

		//クリックした場所の緯度経度
		const { longitude, latitude } = image.getCoordinates(i, j);

		//クリックした場所の値
		const value = image.getValue(i, j);

		//データの単位
		const unit = image.getUnit();

		alert(JSON.stringify({
			longitude,
			latitude,
			value,
			unit,
		}, null, "  "));

	} else {
		//読み込み中の場合
		alert("読み込み完了までお待ちください");
	}
});