
import * as je from "../jaxa.earth.esm.js";

//HTML画面上の要素を取得し、表示内容を初期化します。
const img = document.getElementById("img");
const tid = document.getElementById("tid");
const prog = document.getElementById("prog");
prog.innerHTML = "0%";
const chart = document.getElementById("chart");

//D3を用いてグラフを描画します。
const drawChart = function (images, start, end) {
	const _images = images.slice();
	_images.sort((a, b) => a.getDate().getTime() - b.getDate().getTime());

	const chartdata = [];

	for (let image of _images) {
		chartdata.push({
			date: image.getDate(),
			min: image.stat.min,
			mstd: image.stat.mean - image.stat.stdev,
			mean: image.stat.mean,
			pstd: image.stat.mean + image.stat.stdev,
			max: image.stat.max,
		});
	}

	// console.log(chartdata);

	const chart1 = Plot.plot({
		x: {
			label: "date",
			grid: true,
			tickFormat: d3.timeFormat("%m/%d"),
			domain: [start, end],
		},
		y: {
			label: "value",
			grid: true,
		},
		marks: [
			Plot.line(chartdata, {
				x: "date",
				y: "mean",
				marker: "circle",
				stroke: "#0000ff",
			}),
			Plot.text(chartdata, {
				x: "date",
				y: "mean",
				text: d => d.mean.toFixed(2),
				dy: 10,
			}),

			Plot.line(chartdata, {
				x: "date",
				y: "max",
				marker: "circle",
				stroke: "#ff0000",
			}),
			Plot.line(chartdata, {
				x: "date",
				y: "min",
				marker: "circle",
				stroke: "#ff0000",
			}),
			Plot.line(chartdata, {
				x: "date",
				y: "mstd",
				marker: "circle",
				stroke: "#ccccff",
			}),
			Plot.line(chartdata, {
				x: "date",
				y: "pstd",
				marker: "circle",
				stroke: "#ccccff",
			}),
		],
	});

	chart.innerHTML = "";
	chart.appendChild(chart1);
};


// const collection = "https://s3.ap-northeast-1.wasabisys.com/je-pds/cog/v1/NASA.EOSDIS_Aqua.MODIS_MYD11C1-LST.daytime.v061_global_half-monthly-normal/collection.json";
// const bbox = [110, 30, 150, 50];
// // const bbox = [-180, -90, 180, 90];
// const start = new Date(Date.UTC(2000, 1 - 1, 1));
// const end = new Date(Date.UTC(2000, 12 - 1, 31));
// const colorMap = {
// 	min: -20 + 273.15,
// 	max: 50 + 273.15,
// 	colors: "jet"
// };

// const collection = "https://s3.ap-northeast-1.wasabisys.com/je-pds/cog/v1/JAXA.EORC_GSMaP_standard.Gauge.00Z-23Z.v6_half-monthly-normal/collection.json";
// // const bbox = [100, 20, 160, 50];
// const bbox = [-180, -90, 180, 90];
// const start = new Date(Date.UTC(2000, 1 - 1, 1));
// const end = new Date(Date.UTC(2000, 12 - 1, 31));
// const colorMap = {
// 	min: 0.1,
// 	max: 30,
// 	colors: "jet",
// 	deleteMin: true,
// 	log10: true,
// };

const collection = "https://s3.ap-northeast-1.wasabisys.com/je-pds/cog/v1/JAXA.JASMES_Terra.MODIS-Aqua.MODIS_ndvi.v811_global_half-monthly-normal/collection.json";
// const lng = 118.4;
// const lat = 57.3;
// const dl = 10;
// const bbox = [lng - dl * 2, lat - dl, lng + dl * 2, lat + dl];
// const bbox = [100, 20, 160, 50];
const bbox = [-180, -90, 180, 90];
const start = new Date(Date.UTC(2000, 1 - 1, 1));
const end = new Date(Date.UTC(2000, 12 - 1, 31));
const colorMap = {
	min: 0,
	max: 1,
	colors: "ndvi",
};


//読み込み中の表示をするために、すでに読み込まれたデータを持っておくための仮配列
const tmpimages = [];

let images = await je.getTimeSeriesImage({
	collection,
	bbox,
	start,
	end,
	width: 400,
	height: 200,
	colorMap,

	//バイリニアリサンプリングを使用(未指定時は高速なニアレストネイバーを使用)
	// bilinearResampling: true,

	//時刻ごとデータ(image)が取得されるたびに実行される関数です。
	onloading: function (image, progress) {
		console.log(image.getFormattedDate());

		if (image.ready()) {
			//データを正常に取得できた場合

			//読込状況を随時表示
			img.src = image.getCanvas().toDataURL();
			tid.innerHTML = image.getFormattedDate();
			prog.innerHTML = progress.toFixed(1) + "%";

			//imageオブジェクト内に画像(DataURL形式)と統計値を持たせる
			image.src = image.getCanvas().toDataURL();
			image.stat = je.data.stat(image.data);

			tmpimages.push(image);

			//読み込み中もグラフを随時更新
			drawChart(tmpimages, start, end);

		} else {
			//データを取得できないものがあった場合
			console.log("データ欠損: ", image.getTid());
		}
	},
});

//onloadingの関数内で各imageに付与されたsrc,statプロパティ、setColorMapの実行結果も含まれる
console.log(images);

//欠損しているもの（image.ready() = false）を削除
images = images.filter(image => image.ready());

//欠損しているもの（全画素NaN）を削除
images = images.filter(image => image.getData().validPixels != 0);

//データ読み込み完了後にグラフを表示
drawChart(images, start, end);


//読み込まれた画像をアニメーションで表示
let i = 0;
setInterval(function () {
	img.src = images[i].src;
	tid.innerHTML = images[i].getFormattedDate();

	i++;
	if (i >= images.length) i = 0;
}, 200);
